.. py:module:: pvpltools.module_efficiency

Module efficiency modelling
===========================

.. autosummary::
   :toctree: generated/

   fit_efficiency_model
   adr
   heydenreich
   motherpv
   pvgis
   mpm6
   mpm5
   fit_bilinear
   bilinear
